@@ -16,23 +16,43 @@
 
 #include "convert.h"
 
-#include <KLocale>
-
 #include <QStringList>
 
 namespace KgpgCore
 {
 
+static QString _describe_key_strength(KgpgKeyAlgo algorithm, const uint size, const QString &curve)
+{
+    const char *prefix = NULL;
+
+    if (curve.length() > 0)
+        return curve;
+
+    switch(algorithm)
+    {
+    case ALGO_RSA: prefix = "rsa"; break;
+    case ALGO_ELGAMAL: prefix = "elg"; break;
+    case ALGO_DSA: prefix = "dsa"; break;
+    }
+
+    if (prefix) {
+        return QString("%1%2").arg(prefix, QString::number(size));
+    }
+
+    return QString("%1").arg(size);
+}
+
 //BEGIN KeySub
 KgpgKeySubPrivate::KgpgKeySubPrivate(const QString &id, const uint size, const KgpgKeyTrust trust, const KgpgKeyAlgo algo,
-                                     const KgpgSubKeyType type, const QDateTime &date)
+                                     const KgpgSubKeyType type, const QDateTime &date, const QString &curve)
     : gpgsubvalid(false),
     gpgsubid(id),
     gpgsubsize(size),
     gpgsubcreation(date),
     gpgsubtrust(trust),
     gpgsubalgo(algo),
-    gpgsubtype(type)
+    gpgsubtype(type),
+    gpgcurve(curve)
 {
 }
 
@@ -50,8 +70,8 @@ bool KgpgKeySubPrivate::operator==(const KgpgKeySubPrivate &other) const
 }
 
 KgpgKeySub::KgpgKeySub(const QString &id, const uint size, const KgpgKeyTrust trust, const KgpgKeyAlgo algo, const KgpgSubKeyType type,
-                       const QDateTime &date)
-    : d(new KgpgKeySubPrivate(id, size, trust, algo, type, date))
+                       const QDateTime &date, const QString &curve)
+    : d(new KgpgKeySubPrivate(id, size, trust, algo, type, date, curve))
 {
 }
 
@@ -80,6 +100,11 @@ uint KgpgKeySub::size() const
     return d->gpgsubsize;
 }
 
+QString KgpgKeySub::strength() const
+{
+    return _describe_key_strength(algorithm(), size(), d->gpgcurve);
+}
+
 bool KgpgKeySub::unlimited() const
 {
     return d->gpgsubexpiration.isNull();
@@ -115,6 +140,11 @@ KgpgSubKeyType KgpgKeySub::type() const
     return d->gpgsubtype;
 }
 
+QString KgpgKeySub::curve() const
+{
+    return d->gpgcurve;
+}
+
 bool KgpgKeySub::operator==(const KgpgKeySub &other) const
 {
     if (d == other.d) return true;
@@ -134,7 +164,7 @@ KgpgKeySub& KgpgKeySub::operator=(const KgpgKeySub &other)
 //BEGIN Key
 
 KgpgKeyPrivate::KgpgKeyPrivate(const QString &id, const uint size, const KgpgKeyTrust trust, const KgpgKeyAlgo algo, const KgpgSubKeyType subtype,
-                               const KgpgSubKeyType keytype, const QDateTime &creationDate)
+                               const KgpgSubKeyType keytype, const QDateTime &creationDate, const QString &curve)
     : gpgkeysecret(false),
     gpgkeyvalid(false),
     gpgkeyid(id),
@@ -144,6 +174,7 @@ KgpgKeyPrivate::KgpgKeyPrivate(const QString &id, const uint size, const KgpgKey
     gpgkeyalgo(algo),
     gpgsubtype(subtype),
     gpgkeytype(keytype),
+    gpgcurve(curve),
     gpgsublist(new KgpgKeySubList())
 {
 }
@@ -170,8 +201,8 @@ bool KgpgKeyPrivate::operator==(const KgpgKeyPrivate &other) const
 }
 
 KgpgKey::KgpgKey(const QString &id, const uint size, const KgpgKeyTrust trust, const KgpgKeyAlgo algo, const KgpgSubKeyType subtype,
-                 const KgpgSubKeyType keytype, const QDateTime &creationDate)
-    : d(new KgpgKeyPrivate(id, size, trust, algo, subtype, keytype, creationDate))
+                 const KgpgSubKeyType keytype, const QDateTime &creationDate, const QString &curve)
+    : d(new KgpgKeyPrivate(id, size, trust, algo, subtype, keytype, creationDate, curve))
 {
 }
 
@@ -265,26 +296,49 @@ uint KgpgKey::size() const
     return d->gpgkeysize;
 }
 
+QString KgpgKey::strength() const
+{
+    return _describe_key_strength(algorithm(), size(), d->gpgcurve);
+}
+
 uint KgpgKey::encryptionSize() const
 {
-	const KgpgKeySub *enc = NULL;
+	const KgpgKeySub *enc = Q_NULLPTR;
 	// Get the first encryption subkey
-	for (int i = 0; i < d->gpgsublist->count(); ++i) {
-		const KgpgKeySub &temp = d->gpgsublist->at(i);
-		if (temp.type() & SKT_ENCRYPTION) {
+	foreach (const KgpgKeySub &k, *d->gpgsublist) {
+		if (k.type() & SKT_ENCRYPTION) {
 			// if the first encryption subkey is expired
 			// check if there is one that is not
-			if (temp.trust() > TRUST_EXPIRED)
-				return temp.size();
-			if (enc == NULL)
-				enc = &temp;
+			if (k.trust() > TRUST_EXPIRED)
+				return k.size();
+			if (enc == Q_NULLPTR)
+				enc = &k;
 		}
 	}
-	if (enc != NULL)
+	if (enc != Q_NULLPTR)
 		return enc->size();
 	return 0;
 }
 
+QString KgpgKey::encryptionStrength() const
+{
+    const KgpgKeySub *enc = Q_NULLPTR;
+    // Get the first encryption subkey
+    foreach (const KgpgKeySub &k, *d->gpgsublist) {
+        if (k.type() & SKT_ENCRYPTION) {
+            // if the first encryption subkey is expired
+            // check if there is one that is not
+            if (k.trust() > TRUST_EXPIRED)
+                return _describe_key_strength(k.algorithm(), k.size(), k.curve());
+            if (enc == Q_NULLPTR)
+                enc = &k;
+        }
+    }
+    if (enc != Q_NULLPTR)
+        return _describe_key_strength(enc->algorithm(), enc->size(), enc->curve());
+    return QString("");
+}
+
 gpgme_validity_t KgpgKey::ownerTrust() const
 {
     return d->gpgkeyownertrust;
@@ -318,18 +372,16 @@ KgpgKeyAlgo KgpgKey::algorithm() const
 KgpgKeyAlgo KgpgKey::encryptionAlgorithm() const
 {
 	// Get the first encryption subkey
-	for (int i = 0; i < d->gpgsublist->count(); ++i) {
-		KgpgKeySub temp = d->gpgsublist->at(i);
-		if (temp.type() & SKT_ENCRYPTION) {
-			return temp.algorithm();
-		}
-	}
+	foreach (const KgpgKeySub &k, *d->gpgsublist)
+		if (k.type() & SKT_ENCRYPTION)
+			return k.algorithm();
+
 	return ALGO_UNKNOWN;
 }
 
 KgpgSubKeyType KgpgKey::subtype() const
 {
-	return d->gpgsubtype;
+    return d->gpgsubtype;
 }
 
 KgpgSubKeyType KgpgKey::keytype() const
@@ -337,6 +389,11 @@ KgpgSubKeyType KgpgKey::keytype() const
 	return d->gpgkeytype;
 }
 
+QString KgpgKey::curve() const
+{
+    return d->gpgcurve;
+}
+
 KgpgKeySubListPtr KgpgKey::subList() const
 {
     return d->gpgsublist;
